package com.sky.controller.admin;

import com.sky.common.result.Result;
import com.sky.pojo.vo.OrderReportVO;
import com.sky.pojo.vo.SalesTop10ReportVO;
import com.sky.pojo.vo.TurnoverReportVO;
import com.sky.pojo.vo.UserReportVO;
import com.sky.service.ReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.time.LocalDate;

@RestController
@RequiredArgsConstructor
@RequestMapping("/admin/report")
@Slf4j
@Api(tags = "统计报表相关接口")
public class ReportController {
    private final ReportService reportService;

    @GetMapping("/turnoverStatistics")
    @ApiOperation(value = "营业额数据统计")
    public Result<TurnoverReportVO> turnoverStatistics(@DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate begin, @DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate end) {
        log.info("营业额数据统计：开始时间：{}，结束时间：{}", begin, end);
        TurnoverReportVO turnover = reportService.getTurnover(begin, end);
        return Result.success(turnover);
    }

    @GetMapping("/userStatistics")
    @ApiOperation(value = "用户数据统计")
    public Result<UserReportVO> userStatistics(
            @DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate begin,
            @DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate end) {
        log.info("用户数据统计：开始时间：{}，结束时间：{}", begin, end);
        UserReportVO userStatistics = reportService.getUserStatistics(begin, end);
        return Result.success(userStatistics);
    }

    @GetMapping("ordersStatistics")
    @ApiOperation(value = "订单统计接口")
    public Result<OrderReportVO> ordersStatistics(@DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate begin,
                                                  @DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate end) {
        log.info("订单统计接口：开始时间：{}，结束时间：{}", begin, end);
        OrderReportVO orderReportVO = reportService.getOrdersStatistics(begin, end);
        return Result.success(orderReportVO);
    }

    @GetMapping("top10")
    @ApiOperation(value = "查询销量排名top10接口")
    public Result<SalesTop10ReportVO> top10(@DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate begin,
                                            @DateTimeFormat(pattern = "yyyy-MM-dd") LocalDate end) {
        log.info("订单统计接口：开始时间：{}，结束时间：{}", begin, end);
        SalesTop10ReportVO top10Report = reportService.getTop10Statistics(begin, end);
        return Result.success(top10Report);
    }

    @GetMapping("export")
    @ApiOperation(value = "导出Excel报表接口")
    public void export(HttpServletResponse response) {
        log.info("导出Excel报表接口");
        reportService.exportBusinessData(response);
    }
}
