package com.sky.mapper;

import com.sky.pojo.entity.ShoppingCart;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface ShoppingCartMapper {

    /**
     * 查询购物车
     *
     * @param shoppingCart 根据用户id查询购物车
     * @return 购物车列表
     */
    List<ShoppingCart> list(ShoppingCart shoppingCart);

    /**
     * 根据id更新购物车数量
     *
     * @param shoppingCart 购物车数据
     */
    void updateById(ShoppingCart shoppingCart);

    /**
     * 插入购物车
     *
     * @param shoppingCart 购物车数据
     */
    void insert(ShoppingCart shoppingCart);

    /**
     * 根据用户id删除购物车
     *
     * @param userId 用户id
     */
    void deleteByUserId(Long userId);

    /**
     * 根据购物车id删除购物车内容
     *
     * @param cartId 购物车id
     */
    void deleteById(Long cartId);

    /**
     * 根据购物车id更新购物车内容
     *
     * @param cart 购物车内容
     */
    void updateNumberById(ShoppingCart cart);

    /**
     * 将购物车对象批量添加到数据库
     *
     * @param shoppingCartList 购物车列表
     */
    void insertBatch(List<ShoppingCart> shoppingCartList);
}
