package com.sky.service;


import com.sky.common.result.PageResult;
import com.sky.pojo.dto.*;
import com.sky.pojo.vo.OrderPaymentVO;
import com.sky.pojo.vo.OrderStatisticsVO;
import com.sky.pojo.vo.OrderSubmitVO;
import com.sky.pojo.vo.OrderVO;

public interface OrderService {

    /**
     * 用户下单
     *
     * @param ordersSubmitDTO 订单提交
     * @return OrderSubmitVO
     */
    OrderSubmitVO submitOrder(OrdersSubmitDTO ordersSubmitDTO);

    /**
     * 订单支付
     *
     * @param ordersPaymentDTO 订单提交
     * @return OrderPaymentVO
     */
    OrderPaymentVO payment(OrdersPaymentDTO ordersPaymentDTO) throws Exception;

    /**
     * 支付成功，修改订单状态
     *
     * @param outTradeNo String
     */
    void paySuccess(String outTradeNo);


    /**
     * 历史订单
     *
     * @param page     当前页
     * @param pageSize 一页大小
     * @param status   订单状态 1待付款 2待接单 3已接单 4派送中 5已完成 6已取消
     * @return 订单列表
     */
    PageResult pageQuery4User(int page, int pageSize, Integer status);

    /**
     * 催单
     *
     * @param id 订单id
     */
    void reminder(Long id);

    /**
     * 查询订单详情
     *
     * @param id 订单id
     * @return 订单详情
     */
    OrderVO details(Long id);

    /**
     * 取消订单
     *
     * @param id 订单id
     */
    void cancel(Long id);

    /**
     * 取消订单-商家
     *
     * @param dto 订单
     */
    void cancelBusiness(OrdersCancelDTO dto);

    /**
     * 再来一单
     *
     * @param id 订单id
     */
    void repetition(Long id);

    /**
     * 订单搜索
     *
     * @param dto 订单详情
     * @return 分页数据
     */
    PageResult<OrderVO> conditionSearch(OrdersPageQueryDTO dto);

    /**
     * 各个状态的订单数量统计
     *
     * @return OrderStatisticsVO
     */
    OrderStatisticsVO statistics();

    /**
     * 接单
     *
     * @param dto 接单请求
     */
    void confirm(OrdersConfirmDTO dto);

    /**
     * 拒单
     *
     * @param dto 拒单请求
     */
    void rejection(OrdersRejectionDTO dto);

    /**
     * 派送订单
     *
     * @param id 订单id
     */
    void delivery(Long id);

    /**
     * 完成订单
     *
     * @param id 订单id
     */
    void complete(Long id);
}
